f coefficient allows adjusting weight given to each of these two criteria.abund(x, f=0.2)
## S3 method for class 'abund':
summary(abd)
## S3 method for class 'abund':
plot(abd, n=abd$n, lvert=TRUE, lvars=TRUE, lcol=2, llty=2,
all=TRUE, dlab=c("cumsum", "\% log(ind.)", "% non-zero"),
dcol=c(1, 2, 4), dlty, dpos=c(1.5, 20), ...)
## S3 method for class 'abund':
lines(abd, n=abd$n, lvert=TRUE, lvars=TRUE, \dots)
## S3 method for class 'abund':
identify(abd, label.pts=FALSE, lvert=TRUE, lvars=TRUE, \dots)
## S3 method for class 'abund':
extract(abd, n=abd$n, left=TRUE)1-f. The default value, f=0.2, gives enough weight to the number of non-null values to get abundant speciesabundTRUE then a vertical line separate the n variables at left from the othersTRUE then the x-axis labels of the n left variables are printed in a different color to emphasize themlvert=TRUE) and the variables labels (lvars=TRUE) at left af the nth variable. By default, color 2 is usedlvert=TRUE). By default, a dashed line is usedTRUE then all lines are drawn (cumsum, %log(ind.) and %non-null). If FALSE, only the cumsum line is drawnall=TRUEidentify() method?TRUE, the n variables at left are extracted. Otherwise, the total-n variables at right are extractedprint(), summary(), plot(), lines(), identify(), extract().f = 0.2, followed by an extraction of rare species and another sort with f = 1 allows to collect only rare but locally abundant species.escoufdata(bnr)
bnr.abd <- abund(bnr)
summary(bnr.abd)
plot(bnr.abd, dpos=c(105, 100))
bnr.abd$n <- 26
# To identify a point on the graph, use: bnr.abd$n <- identify(bnr.abd)
lines(bnr.abd)
bnr2 <- extract(bnr.abd)
names(bnr2)Run the code above in your browser using DataLab