pennington(x, calc="all", na.rm=FALSE)"mean", "var", "mean.var" or "all" (by default) for the mean, the variance, the variance of the mean or all these three statitics, respectivelyna.rm=TRUE, missing data are eliminated first. If it is FALSE (by default), any missing value in the series leads to NA as the result for the statisticcalc="all"pennington() calculates thus statistics for such conditional lognormal distributions.stat.pen, stat.slidedata(marbio)
pennington(marbio[, "Copepodits2"])
pennington(marbio[, "Copepodits2"], calc="mean", na.rm=TRUE)Run the code above in your browser using DataLab