Learn R Programming

pastecs (version 1.0-2)

regul.adj: Adjust regulation parameters

Description

Calculate and plot an histogram of the distances between interpolated observations in a regulated time series and closest observations in the initial irregular time series. This allows to optimise the tol parameter

Usage

regul.adj(x, xmin=min(x), frequency=NULL, deltat, tol=deltat,
        tol.type="both", nclass=50, col=c(4, 5, 2), plotit=TRUE, ...)

Arguments

x
a vector with times corresponding to the observations in the irregular initial time series
xmin
the time corresponding to the first observation in the regular time series
frequency
the frequency of observations in the regular time series
deltat
the interval between two successive observations in the regular time series. This is the inverse of frequency. Only one of both parameters need to be given. If both are provided, frequency supersedes deltat
tol
the tolerance in the difference between two matching observations (in the original irregular series and in the regulated series). If tol=0 both values must be strictly identical; a higher value for tol allows some fuzzy matching.
tol.type
the type of window to use for the time-tolerance: "left", "right", "both" (by default) or "none". If tol.type="left", corresponding x values are seeked in a window ]xregul-tol,
nclass
the number of classes to compute in the histogram. This is indicative, and will be adjusted by the algorithm to produce a nicely-formatted histogram. The default value is nclass=50. It is acceptable in many cases, but if the histogram is not
col
the three colors to use to represent respectively the fist bar (exact coincidence), the middle bars (coincidence in a certain tolerance window) and the last bar (values always interpolated). By default, col=c(4,5,2)
plotit
if plotit=TRUE then the histogram is plotted. Otherwise, it is only calculated
...
additional graph parameters for the histogram

Value

  • A list with components:
  • paramsthe parameters used for the regular time-scale
  • matchthe number of matching observations in the tolerance window
  • exact.matchthe number of exact matching observations
  • match.countsa vector with the number of matching observations for increasing values of tol

synopsis

regul.adj(x, xmin=min(x), frequency=NULL, deltat=(max(x, na.rm = T) - min(x, na.rm = T))/(length(x) - 1), tol=deltat, tol.type="both", nclass=50, col=c(4, 5, 2), xlab=paste("Time distance"), ylab=paste("Frequency"), main="Number of matching observations", plotit=TRUE, ...)

Details

This function is complementary to regul.screen(). While the later look for the best combination of the number of observations, the interval between observations and the position of the first observation on the time-scale for the regular time series, regul.adj() look for the optimal value for tol, the tolerance window.

See Also

regul.screen, regul

Examples

Run this code
# This example follows the example for regul.screen()
# where we determined that xmin=9, deltat=21, n=63, with tol=1.05
# is a good choice to regulate the irregular time series in 'releve' 
data(releve)
regul.adj(releve$Day, xmin=9, deltat=21)
# The histogram indicates that it is not useful to increase tol
# more than 1.05, because few observations will be added
# except if we increase it to 5-7, but this value could be
# considered to be too large in comparison with deltat=22
# On the other hand, with tol <= 1, the number of matching
# observations will be almost divided by two!

Run the code above in your browser using DataLab