Usage
regul.adj(x, xmin=min(x), frequency=NULL, deltat, tol=deltat,
tol.type="both", nclass=50, col=c(4, 5, 2), plotit=TRUE, ...)Arguments
x
a vector with times corresponding to the observations in the irregular initial time series
xmin
the time corresponding to the first observation in the regular time series
frequency
the frequency of observations in the regular time series
deltat
the interval between two successive observations in the regular time series. This is the inverse of frequency. Only one of both parameters need to be given. If both are provided, frequency supersedes deltat
tol
the tolerance in the difference between two matching observations (in the original irregular series and in the regulated series). If tol=0 both values must be strictly identical; a higher value for tol allows some fuzzy matching.
tol.type
the type of window to use for the time-tolerance: "left", "right", "both" (by default) or "none". If tol.type="left", corresponding x values are seeked in a window ]xregul-tol,
nclass
the number of classes to compute in the histogram. This is indicative, and will be adjusted by the algorithm to produce a nicely-formatted histogram. The default value is nclass=50. It is acceptable in many cases, but if the histogram is not
col
the three colors to use to represent respectively the fist bar (exact coincidence), the middle bars (coincidence in a certain tolerance window) and the last bar (values always interpolated). By default, col=c(4,5,2)
plotit
if plotit=TRUE then the histogram is plotted. Otherwise, it is only calculated
...
additional graph parameters for the histogram
synopsis
regul.adj(x, xmin=min(x), frequency=NULL, deltat=(max(x, na.rm = T) - min(x, na.rm = T))/(length(x) - 1), tol=deltat, tol.type="both", nclass=50, col=c(4, 5, 2), xlab=paste("Time distance"), ylab=paste("Frequency"), main="Number of matching observations", plotit=TRUE, ...)